OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Datoteke v souporabi",
    "Downloaded via public link" : "Prejeto po javni povezavi",
    "Downloaded by {email}" : "Prejeto po {email}",
    "{file} downloaded via public link" : "Datoteka {file} je prejeta po javni povezavi",
    "{email} downloaded {file}" : "{email} prejme datoteko {file}",
    "Shared with group {group}" : "V souporabi skupine {group}",
    "Removed share for group {group}" : "Odstranjeno je mesto souporabe za skupino {group}",
    "{actor} shared with group {group}" : "{actor} omogoči souporabo s skupino {group}",
    "{actor} removed share for group {group}" : "{actor} odstrani možnost souporabe s skupine {group}",
    "Share for group {group} expired" : "Souporaba je za skupino {group} potekla",
    "You shared {file} with group {group}" : "Omogočite souporabo datoteke {file} s skupino {group}",
    "You removed group {group} from {file}" : "Odstranite skupino {group} z datoteke {file}",
    "{actor} shared {file} with group {group}" : "{actor} omogoči souporabo datoteke {file} s skupino {group}",
    "{actor} removed group {group} from {file}" : "{actor} odstrani skupino {group} z datoteke {file}",
    "Share for file {file} with group {group} expired" : "Souporaba datoteke {file} s skupino {group} je potekla",
    "Shared as public link" : "V souporabi z javno povezavo",
    "Removed public link" : "Javno povezava je odstranjena",
    "Public link expired" : "javna povezava je pretekla",
    "{actor} shared as public link" : "{actor} objavi mesto souporabe z javno povezavo",
    "{actor} removed public link" : "{actor} odstrani javno povezavo",
    "Public link of {actor} expired" : "Javna povezava, ki jo objavi {actor} je pretekla",
    "You shared {file} as public link" : "Omogočite souporabo datoteke {file} z javno povezavo",
    "You removed public link for {file}" : "Odstranite povezavo do datoteke {file}",
    "Public link expired for {file}" : "Preteče javna povezava do datoteke {file}",
    "{actor} shared {file} as public link" : "{actor} omogoči souporabo datoteke {file} z javno povezavo",
    "{actor} removed public link for {file}" : "{actor} odstrani javno povezavo do {file}",
    "Public link of {actor} for {file} expired" : "Javna povezava, ki jo omogoča {actor} za datoteko {file} je potekla",
    "{user} accepted the remote share" : "Uporabnik {user} potrdi oddaljeno souporabo",
    "{user} declined the remote share" : "{user} zavrne oddaljeno souporabo",
    "You received a new remote share {file} from {user}" : "{user} vam pošlje povezavo do oddaljenega mesta za datoteko {file}",
    "{user} accepted the remote share of {file}" : "Uporabnik {user} potrdi oddaljeno souporabo {file}",
    "{user} declined the remote share of {file}" : "{user} zavrne povezavo do oddaljenega mesta za datoteko {file}",
    "{user} unshared {file} from you" : "{user} vam onemogoči souporabo datoteke {file}.",
    "Shared with {user}" : "Shared with {user}",
    "Removed share for {user}" : "Prekinete souporab za uporabnika {user}.",
    "You removed yourself" : "Odstranite sami sebe",
    "{actor} removed themselves" : "{actor} se odstrani",
    "{actor} shared with {user}" : "{actor} omogoči souporabo z uporabnikom {user}",
    "{actor} removed share for {user}" : "{actor} prekine souporabo z uporabnikom {user}",
    "Shared by {actor}" : "Souporaba: {actor}",
    "{actor} removed share" : "{actor} odstrani mesto souporabe",
    "Share for {user} expired" : "Mesto souporabe je za uporabnika {user} poteklo",
    "Share expired" : "Dovoljenje souporabe je preteklo",
    "You shared {file} with {user}" : "Omogočite souporabo datoteke {file} z uporabnikom {user}",
    "You removed {user} from {file}" : "Uporabniku {user} prekinete dostop do datoteke {file}.",
    "You removed yourself from {file}" : "Sami sebe odstranite z datoteke {file}",
    "{actor} removed themselves from {file}" : "{actor} se odstrani z datoteke {file}",
    "{actor} shared {file} with {user}" : "{actor}  omogoči souporabo datoteke {file} z uporabnikom {user}",
    "{actor} removed {user} from {file}" : "{actor} prekine souporabo datoteke {file} z uporabnikom {user}",
    "{actor} shared {file} with you" : "{actor} vam omogoči souporabo {file}",
    "{actor} removed you from the share named {file}" : "{actor} vas odstrani s souporabe datoteke {file}",
    "Share for file {file} with {user} expired" : "Souporaba datoteke {file} z uporabnikom {user} je potekla",
    "Share for file {file} expired" : "Souporaba datoteke {file} je potekla",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Datoteko oziroma mapo v souporabi po elektronski pošti oziroma javni povezavi je uporabnik <strong>prejel na svoj krajevni disk</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Datoteka ali mapa je bila dodana v souporabo na <strong>drugem strežniku</strong>",
    "Sharing" : "Souporaba",
    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>",
    "Shared link" : "Povezava do mesta souporabe",
    "Wrong share ID, share does not exist" : "Napačen ID mesta souporabe; mesto ne obstaja!",
    "Could not delete share" : "Mesta souporabe ni mogoče izbrisati",
    "Please specify a file or folder path" : "Določiti je treba datoteko ali pot do mape",
    "Wrong path, file/folder does not exist" : "Napačna pot; datoteka ali mapa ne obstaja",
    "Could not create share" : "Mesta souporabe ni mogoče ustvariti",
    "Please specify a valid account to share with" : "Navesti je treba veljaven račun za omogočanje souporabe",
    "Group sharing is disabled by the administrator" : "Skupinska souporaba je skrbniško onemogočena",
    "Please specify a valid group" : "Navesti je treba veljavno skupino",
    "Public link sharing is disabled by the administrator" : "Souporaba z uporabo javne povezave je skrbniško onemogočena",
    "Please specify a valid email address" : "Navesti je treba veljaven elektronski naslov",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Souporaba %s s pošiljanjem gesla prek programa Nextcloud Talk je spodletela, ker program Talk ni omogočen.",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Souporaba %1$s je spodletela, ker ozadnji program ne omogoča souporabe prek vrste %2$s.",
    "Please specify a valid federated account ID" : "Navesti je treba veljaven ID zveznega računa",
    "Please specify a valid federated group ID" : "Navesti je treba veljaven ID zvezne skupine",
    "Sharing %s failed because the back end does not support room shares" : "Souporaba %s je spodletela, ker sistem ne dovoli souporabe znotraj posameznih sob",
    "Unknown share type" : "Neznana vrsta mesta souporabe",
    "Not a directory" : "Predmet ni mapa",
    "Could not lock node" : "Vozlišča ni mogoče zakleniti",
    "Public upload is only possible for publicly shared folders" : "Javno pošiljanje v oblak je mogoče le za mape v javni skupni rabi.",
    "Share must at least have READ or CREATE permissions" : "Mestu souporabe mora biti dodeljeno vsaj dovoljenje BRANJE in USTVARJANJE",
    "Public upload disabled by the administrator" : "Javno pošiljanje v oblak je skrbniško onemogočeno",
    "Could not lock path" : "Poti ni mogoče zakleniti",
    "You are not allowed to edit incoming shares" : "Ni ustreznih dovoljenj za urejanje dodeljenih mest souporabe",
    "Wrong or no update parameter given" : "Parameter posodobitve ni podan, ali pa je navedena napačna vrednost",
    "Wrong password" : "Napačno geslo",
    "shared by %s" : "souporaba: %s",
    "Download" : "Prejmi",
    "Add to your %s" : "Dodaj v %s",
    "Direct link" : "Neposredna povezava",
    "Share API is disabled" : "Vmesnik API za souporabo je onemogočen",
    "File sharing" : "Souporaba datotek",
    "Share will expire tomorrow" : "Souporaba bo jutri pretekla",
    "Your share of {node} will expire tomorrow" : "Suporaba vozlišča {node} bo jutri pretekla.",
    "You received {share} as a share by {user}" : "{user} vam omogoča souporabo {share}",
    "You received {share} to group {group} as a share by {user}" : "{user} vam omogoča souporabo {share} prek skupine {group}",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "you" : "vi",
    "Expiration date" : "Datum preteka",
    "Select a date" : "Izbor datuma",
    "Set a password" : "Nastavi geslo",
    "Password" : "Geslo",
    "Enter a valid password" : "Vpisati je treba veljavno geslo",
    "Generate a new password" : "Ustvari novo geslo",
    "Your administrator has enforced a password protection." : "Skrbnik zahteva uporabo zaščite z geslom.",
    "Link copied" : "Povezava je kopirana",
    "Email already added" : "Elektronski naslov je že dodan",
    "Invalid email address" : "Vpisan je neveljaven elektronski naslov",
    "Share link" : "Povezava za souporabo",
    "Copy" : "Kopiraj",
    "Send link via email" : "Pošlji povezavo po elektronski pošti",
    "Remove email" : "Odstrani elektronski naslov",
    "Select a destination" : "Izbor cilja",
    "Select" : "Izbor",
    "Where should these files go?" : "Kam želite poslati te datoteke?",
    "Upload destination" : "Mesto pošiljanja",
    "Revert to default" : "Povrni na privzeto",
    "The uploaded files are visible only to you unless you choose to share them." : "V oblak poslane datoteke so vidne le vam, dokler jih ne omogočite v souporabo.",
    "Add a note" : "Dodaj opombo",
    "Note for recipient" : "Opomba za prejemnika",
    "Add a note to help people understand what you are requesting." : "Dodajte opombo, ki bo prejemnikom pomagala razumeti, kaj od njih zahtevate.",
    "Close" : "Zapri",
    "File request created" : "Zahteva za datoteko je ustvarjena",
    "Error creating the share: {errorMessage}" : "Napaka pri ustvarjanju mesta souporabe: {errorMessage}",
    "Error creating the share" : "Napaka ustvarjanja mesta souporabe",
    "Error sending emails" : "Prišlo je do napake med pošiljanjem elektronskih sporočil",
    "Create a file request" : "Ustvari zahtevo za datoteko",
    "Previous step" : "Predhodni korak",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "Error while toggling options" : "Prišlo je do napake med preklapljanjem možnosti",
    "Choose a default folder for accepted shares" : "Izbor privzete mape za sprejemanje map v souporabi",
    "Invalid path selected" : "Izbrana je neveljavna pot",
    "Unknown error" : "Neznana napaka",
    "Set default folder for accepted shares" : "Izbor privzete mape za sprejemanje map v souporabi",
    "Reset" : "Ponastavi",
    "Reset folder to system default" : "Ponastavi mapo na privzete sistemske vrednosti",
    "group" : "skupina",
    "conversation" : "pogovor",
    "remote" : "oddaljeno",
    "remote group" : "oddaljena skupina",
    "guest" : "gost",
    "Shared with the group {user} by {owner}" : "{owner} omogoči souporabo s člani skupine {user}",
    "Shared with the conversation {user} by {owner}" : "{owner} omogoči souporabo z udeležencem pogovora {user}",
    "Shared with {user} by {owner}" : "Souporabo z {user} omogoča {owner}",
    "Added by {initiator}" : "Dodano: {initiator}",
    "Via “{folder}”" : "Prek mape »{folder}«",
    "Unshare" : "Prekini souporabo",
    "Cannot copy, please copy the link manually" : "Povezave ni mogoče kopirati. Storite to ročno.",
    "Copy internal link" : "Kopiraj krajevno povezavo",
    "Internal link" : "Notranja povezava",
    "Shared via link by {initiator}" : "{initiator} omogoči souporabo prek povezave",
    "Mail share ({label})" : "Souporaba prek elektronske pošte ({label})",
    "Share link ({label})" : "Souporaba povezave ({label})",
    "Share link ({index})" : "Souporaba povezave ({index})",
    "Create public link" : "Ustvari javno povezavo",
    "Actions for \"{title}\"" : "Dejanja za »{title}«",
    "Error, please enter proper password and/or expiration date" : "Napaka. Vpisati je treba pravo geslo ali datum preteka",
    "Link share created" : "Povezava do mesta souporabe je ustvarjena",
    "Error while creating the share" : "Napaka ustvarjanja mesta souporabe",
    "Please enter the following required information before creating the share" : "Vpisati je treba nekatere podrobnosti, preden je mogoče ustvariti mesto souporabe",
    "Password protection (enforced)" : "Zaščita z geslom (vsiljena)",
    "Password protection" : "Zaščita z geslom",
    "Enter a password" : "Vpis gesla",
    "Create share" : "Ustvari predmet souporabe",
    "Customize link" : "Prilagodi povezavo",
    "Generate QR code" : "Ustvari kodo QR",
    "Add another link" : "Dodaj novo povezavo",
    "Create a new share link" : "Ustvari novo povezavo za souporabo",
    "View only" : "Le ogled",
    "Can edit" : "Lahko ureja",
    "Custom permissions" : "Dovoljenja po meri",
    "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
    "Searching …" : "Poteka iskanje ...",
    "No elements found." : "Ni najdenih predmetov",
    "Search everywhere" : "Išči povsod",
    "Guest" : "Gost",
    "Group" : "Skupina",
    "Email" : "Elektronski naslov",
    "Team" : "Skupina",
    "Talk conversation" : "Pogovor Talk",
    "Deck board" : "Zbirka Deck",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "na strežniku {server}",
    "Note:" : "Opomba:",
    "File drop" : "Poteg datotek v mapo",
    "Terms of service" : "Pogoji uporabe storitve",
    "Read" : "Branje",
    "Create" : "Ustvari",
    "Edit" : "Uredi",
    "Share" : "Souporaba",
    "Delete" : "Izbriši",
    "Allow upload and editing" : "Dovoli pošiljanje in urejanje",
    "Allow editing" : "Dovoli urejanje",
    "Upload only" : "Le pošiljanje",
    "Advanced settings" : "Napredne nastavitve",
    "Share label" : "Naziv mesta souporabe",
    "Set password" : "Nastavi geslo",
    "Password expires {passwordExpirationTime}" : "Geslo preteče {passwordExpirationTime}",
    "Password expired" : "Geslo je preteklo",
    "Video verification" : "Video overitev",
    "Expiration date (enforced)" : "Datum preteka (vsiljeno)",
    "Set expiration date" : "Nastavi datum preteka",
    "Hide download" : "Skrij prejem",
    "Note to recipient" : "Sporočilo za prejemnika",
    "Enter a note for the share recipient" : "Vpišite opombo za prejemnika",
    "Delete share" : "Izbriši mesto souporabe",
    "Others with access" : "Drugi z dostopom",
    "Toggle list of others with access to this directory" : "Preklopi seznam drugih z dostopom do te mape",
    "Toggle list of others with access to this file" : "Preklopi seznam drugih z dostopom do te datoteke",
    "Unable to fetch inherited shares" : "Ni mogoče pridobiti podedovanih mest souporabe",
    "Shares" : "V souporabi",
    "Unable to load the shares list" : "Ni mogoče naložiti seznama predmetov v souporabi",
    "Expires {relativetime}" : "Preteče {relativetime}",
    "this share just expired." : "to mesto souporabe je ravnokar preteklo.",
    "Shared with you by {owner}" : "Souporabo omogoča {owner}",
    "Link to a file" : "Povezava do datoteke",
    "Open in Files" : "Odpri v mapi",
    "Shared" : "V souporabi",
    "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
    "Sharing options" : "Možnosti souporabe",
    "Shared with others" : "V souporabi  z drugimi",
    "People" : "Osebe",
    "Public share" : "Javna objava",
    "No shares" : "Ni še vpisanih mest souporabe",
    "Shared with you" : "V souporabi z vami",
    "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
    "Nothing shared yet" : "Souporabe datotek še niste omogočili",
    "Shared by link" : "V souporabi s povezavo",
    "No shared links" : "Ni povezav za souporabo",
    "Deleted shares" : "Izbrisana mesta souporabe",
    "No deleted shares" : "Ni izbrisanih povezav za souporabo.",
    "Pending shares" : "Predmeti za souporabo na čakanju",
    "No pending shares" : "Ni nobenega predmeta za souporabo na čakanju",
    "Error deleting the share" : " Napaka brisanja mesta souporabe",
    "Error updating the share: {errorMessage}" : "Napaka pri posodabljanju mesta souporabe: {errorMessage}",
    "Error updating the share" : "Napaka posodabljanja mesta souporabe",
    "File \"{path}\" has been unshared" : "Souporaba datoteke »{path}« je odstranjena",
    "Folder \"{path}\" has been unshared" : "Souporaba mape »{path}« je odstranjena",
    "Password created successfully" : "Geslo je uspešno ustvarjeno",
    "Error generating password from password policy" : "Napaka ustvarjanja gesla po določenih varnostnih pravilih",
    "Shared with you and the group {group} by {owner}" : "{owner} omogoča vam in skupini {group} souporabo",
    "Shared with you and {circle} by {owner}" : "{owner} omogoči souporabo vam in članom kroga {circle}.",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} omogoči souporabo vam in udeležencem pogovora {conversation}.",
    "Shared with you in a conversation by {owner}" : "{owner} vam omogoči souporabo v pogovoru.",
    "Share not found" : "Mesta souporabe ni mogoče najti.",
    "Back to %s" : "Nazaj na %s",
    "Add to your Nextcloud" : "Dodaj v oblak Nextcloud",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Souporaba %s je spodletela, ker sistem ne podpira souporabe ScienceMesh",
    "Link copied to clipboard" : "Povezava je kopirana v odložišče",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Copy internal link to clipboard" : "Kopiraj notranjo povezavo v odložišče",
    "Copy public link of \"{title}\" to clipboard" : "Kopiraj javno povezavo do mape »{title}« v odložišče",
    "Name or email …" : "Ime ali elektronski naslov ...",
    "Name, email, or Federated Cloud ID …" : "Ime, elektronski naslov, ali ID zveznega oblaka ...",
    "Searching …" : "Poteka iskanje ...",
    "Search globally" : "Splošno iskanje",
    "Name" : "Ime podpisnika",
    "Enter your name" : "Vpišite ime",
    "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
    "Shared by" : "Souporabo omogoča",
    "Shared with" : "V skupni rabi z uporabnikom",
    "Share note" : "Omogoči souporabo zabeležke",
    "Show list view" : "Pokaži seznamski pogled",
    "Show grid view" : "Pokaži mrežni pogled",
    "Upload files to %s" : "Pošlji datoteke v račun %s",
    "Note" : "Opomba",
    "Select or drop files" : "Izberte ali povlecite datoteke",
    "Uploading files" : "Pošiljanje datotek",
    "Uploaded files:" : "Poslane datoteke:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "S pošiljanjem datotek v oblak sprejemate tudi %1$spogoje uporabe storitve%2$s."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
